@@ -40,7 +40,7 @@ from .urls_patterns import URL_ADMIN_SERVER_INFO, URL_ADMIN_CLIENT_AUTHZ_RESOURC
     URL_ADMIN_USER_CLIENT_ROLES_AVAILABLE, URL_ADMIN_USERS, URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID, URL_ADMIN_CLIENT_AUTHZ_POLICIES, \
     URL_ADMIN_CLIENT_AUTHZ_POLICIES_ID, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS_ID, \
     URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES, USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL, \
-    URL_ADMIN_DEFAULT_GROUPS
+    URL_ADMIN_DEFAULT_GROUPS, URL_ADMIN_GROUP_REALM_ROLES
 
 def serialize(obj):
     """JSON serializer for objects not serializable by default json code"""
@@ -647,6 +647,21 @@ class KeycloakAdmin:
                                             data=json.dumps(payload))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
 
+    def assign_realm_group_role(self, group_id, roles):
+        """
+        Assign a realm role to a group
+
+        :param user_id: id of group
+        :param roles: roles list or role (use RoleRepresentation)
+        :return Keycloak server response
+        """
+
+        payload = roles if isinstance(roles, list) else [roles]
+        params_path = {"realm-name": self.realm_name, "id": group_id}
+        data_raw = self.connection.raw_post(URL_ADMIN_GROUP_REALM_ROLES.format(**params_path),
+                                            data=json.dumps(payload))
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
+
     def delete_client_group_roles(self, group_id, client_id, roles):
         """
         Delete client roles from a group.
@@ -1169,7 +1184,7 @@ class KeycloakAdmin:
         payload = roles if isinstance(roles, list) else [roles]
         params_path = {"realm-name": self.realm_name, "id": user_id, "client-id": client_id}
         data_raw = self.connection.raw_delete(URL_ADMIN_USER_CLIENT_ROLES.format(**params_path),
-                                              data=json.dumps(payload))
+                                              data=json.dumps(payload, default=serialize))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
 
     def get_authentication_flows(self):
